@@ -855,7 +855,7 @@ gaussian_maxpos(const cpl_image * self,
         const double M_x = cpl_array_get_double(gauss_parameters, 3, NULL);
         const double M_y = cpl_array_get_double(gauss_parameters, 4, NULL);
 
-        valfit = cpl_gaussian_eval_2d(gauss_parameters, M_x, M_y);
+        valfit = hcpl_gaussian_eval_2d(gauss_parameters, M_x, M_y);
 
         if (!cpl_errorstate_is_equal(prestate)) {
             code = cpl_error_get_code();
