@@ -1813,8 +1813,8 @@ static cpl_error_code naco_img_jitter_reject_objects(cpl_image * self,
 */
 /*----------------------------------------------------------------------------*/
 static cpl_image * naco_img_jitter_saa_lucky(const cpl_imagelist * cube,
-                                             const cpl_vector * strehl,
-                                             const cpl_bivector * offs,
+                                             const cpl_vector    * strehl,
+                                             const cpl_bivector  * offs,
                                              double fraction)
 {
 
@@ -1824,8 +1824,7 @@ static cpl_image * naco_img_jitter_saa_lucky(const cpl_imagelist * cube,
                                1);
     cpl_imagelist * lcube   = NULL;
     const cpl_imagelist * ucube;
-    cpl_vector    * lstrehl = mcube == ncube ? (cpl_vector*)strehl
-        : cpl_vector_duplicate(strehl);
+    cpl_vector    * lstrehl = NULL;
     /* Always need to duplicate due to pesky offset convention in
        cpl_geom_img_offset_saa() */
     cpl_bivector  * loffs   = cpl_bivector_duplicate(offs);
@@ -1845,6 +1844,8 @@ static cpl_image * naco_img_jitter_saa_lucky(const cpl_imagelist * cube,
         double strehlmin; /* Smallest to be used */
         int  * pindex;
 
+        lstrehl = cpl_vector_duplicate(strehl);
+
         tsort = cpl_table_new(ncube);
         psort = cpl_propertylist_new();
 
@@ -1906,8 +1907,7 @@ static cpl_image * naco_img_jitter_saa_lucky(const cpl_imagelist * cube,
         cpl_imagelist_delete(lcube);
     }
 
-    if (lstrehl != strehl)
-        cpl_vector_delete(lstrehl);
+    cpl_vector_delete(lstrehl);
 
     cpl_bivector_delete(loffs);
 
@@ -1946,17 +1946,10 @@ cpl_error_code naco_img_jitter_find_strehl(const cpl_imagelist * self,
     cpl_vector    * sigmas = NULL;
     double          psigmas[] = {5.0, 2.0, 1.0, 0.5}; /* not modified */
     const int       nsigmas = (int)(sizeof(psigmas)/sizeof(double));
-    /* Use half of default value to support images windowed to 128 x 130 */
-    /* FIXME: Adjust according to image size ? */
-    const double    rstar  = 0.5 * IRPLIB_STREHL_STAR_RADIUS;
-    const double    rbgint = 0.5 * IRPLIB_STREHL_BACKGROUND_R1;
-    const double    rbgext = 0.5 * IRPLIB_STREHL_BACKGROUND_R2;
     cpl_size        isigma = 0;
     int             i;
 
 
-    skip_if(rbgext <= rbgint);
-
     bug_if(cpl_imagelist_get_size(self) != nobj);
 
     /* Create the vector for the detection thresholds */
@@ -2028,7 +2021,6 @@ static cpl_image * naco_img_jitter_saa_center(const cpl_imagelist * cube,
 
     const int       ncube  = cpl_imagelist_get_size(cube);
     cpl_image     * self   = NULL;
-    const cpl_image * image;
     cpl_image    ** combined = NULL;
     cpl_imagelist * ccube  = NULL;
     const cpl_imagelist * ucube;
@@ -2066,10 +2058,11 @@ static cpl_image * naco_img_jitter_saa_center(const cpl_imagelist * cube,
 
     if (imin > 0) {
         /* Wrap ccube around the images - with image imin first */
+        /* - the images from cube will _not_ be modified */
+        const cpl_image * image = cpl_imagelist_get_const(cube, imin);
 
         ccube = cpl_imagelist_new();
 
-        image = cpl_imagelist_get_const(cube, imin);
         bug_if(cpl_imagelist_set(ccube, (cpl_image*)image, 0));
 
         for (i = 0; i < imin; i++) {
@@ -2088,8 +2081,8 @@ static cpl_image * naco_img_jitter_saa_center(const cpl_imagelist * cube,
         pos_y = cpl_vector_get(offsy, imin);
 
         /* Move all offsets below imin 1 place up */
-        memmove(doffsx + 1, doffsx, (size_t)imin * sizeof(*doffsx));
-        memmove(doffsy + 1, doffsy, (size_t)imin * sizeof(*doffsy));
+        (void)memmove(doffsx + 1, doffsx, (size_t)imin * sizeof(*doffsx));
+        (void)memmove(doffsy + 1, doffsy, (size_t)imin * sizeof(*doffsy));
 
         /* Copy the imin offset to the 1st element */
         cpl_vector_set(offsx, 0, pos_x);
