@@ -51,6 +51,8 @@
 static cpl_imagelist * naco_img_twflat_reduce(const irplib_framelist *,
                                               const irplib_framelist *);
 
+static cpl_error_code naco_img_twflat_threshold(cpl_image *);
+
 static cpl_error_code naco_img_twflat_qc(cpl_propertylist *,
                                          const irplib_framelist *);
 
@@ -491,6 +493,9 @@ static cpl_imagelist * naco_img_twflat_reduce(const irplib_framelist * f_one,
     /* Normalize gain */
     flat = cpl_imagelist_get(results, 0);
     bug_if( flat == NULL);
+
+    bug_if(naco_img_twflat_threshold(flat));
+
     irplib_check(norm =
                  cpl_image_get_mean_window(flat,
                                            naco_img_twflat_config.rej_left+1,
@@ -517,6 +522,44 @@ static cpl_imagelist * naco_img_twflat_reduce(const irplib_framelist * f_one,
 }
 
 
+/*----------------------------------------------------------------------------*/
+/**
+  @brief    Reset any non-physical gain to 1
+  @param    self The flat to process
+  @return   CPL_ERROR_NONE iff everything is ok
+ */
+/*----------------------------------------------------------------------------*/
+static cpl_error_code naco_img_twflat_threshold(cpl_image * self)
+{
+
+    cpl_stats * fstats = cpl_stats_new_from_image(self, CPL_STATS_MIN
+                                                  | CPL_STATS_MINPOS);
+
+    if (cpl_stats_get_min(fstats) <= 0.0) {
+        cpl_mask  * bpm = cpl_image_get_bpm(self); /* Just an accessor */
+        cpl_size    nbad;
+
+        /* Reject any non-positive pixel */
+        bug_if(cpl_mask_threshold_image(bpm, self, 0.0, DBL_MAX, CPL_BINARY_0));
+        nbad = cpl_image_count_rejected(self);
+        /* Set the gain for any bad pixel to 1 */
+        bug_if(cpl_image_fill_rejected(self, 1.0));
+
+        cpl_msg_warning(cpl_func, "Set %d pixel(s) with non-positive gain "
+                        "(down to %g at (%d,%d)) to 1", (int)nbad,
+                        cpl_stats_get_min(fstats),
+                        (int)cpl_stats_get_min_x(fstats),
+                        (int)cpl_stats_get_min_y(fstats));
+    }
+
+    end_skip;
+
+    cpl_stats_delete(fstats);
+
+    return cpl_error_get_code();
+}
+
+
 /*----------------------------------------------------------------------------*/
 /**
   @brief    Append the QC parameters to the propertylist
